<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

if ( ! function_exists( 'moun10_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Moun10 Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function moun10_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'moun10_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'moun10_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Moun10 Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function moun10_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'moun10_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'moun10_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Moun10 Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function moun10_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'moun10_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if secondary nav section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[slider_content_type]' )->value();
	return moun10_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[slider_content_type]' )->value();
	return moun10_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[slider_content_type]' )->value();
	return moun10_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if slider separator section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_slider_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'moun10_pro_theme_options[slider_content_type]' )->value();
    return moun10_pro_is_slider_section_enable( $control ) && !( 'category' == $content_type );
}
/**
 * Check if about section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[about_content_type]' )->value();
	return moun10_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if slider section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[about_content_type]' )->value();
	return moun10_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if slider section content type is custom.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_about_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[about_content_type]' )->value();
	return moun10_pro_is_about_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if about section content type is custom.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_if_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[about_content_type]' )->value();
	return moun10_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[service_content_type]' )->value();
	return moun10_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if service section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[service_content_type]' )->value();
	return moun10_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if service section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[service_content_type]' )->value();
	return moun10_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if service separator section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_service_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'moun10_pro_theme_options[service_content_type]' )->value();
    return moun10_pro_is_service_section_enable( $control ) && !( 'category' == $content_type );
}
/**
 * Check if service btn url section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_service_section_btn_url_enable( $control ) {
    $content_type = $control->manager->get_setting( 'moun10_pro_theme_options[service_content_type]' )->value();
    return moun10_pro_is_service_section_enable( $control ) && !( 'category' == $content_type );
}
/**
 * Check if destination section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[destination_section_enable]' )->value() );
}
/**
 * Check if destination section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[destination_content_type]' )->value();
	return moun10_pro_is_destination_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if destination section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[destination_content_type]' )->value();
	return moun10_pro_is_destination_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if destination section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[destination_content_type]' )->value();
	return moun10_pro_is_destination_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if destination section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[destination_content_type]' )->value();
	return moun10_pro_is_destination_section_enable( $control ) && ( 'trip' == $content_type );
}
/**
 * Check if testimonial section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_testimonial_section_enable( $control ) {
    return ( $control->manager->get_setting( 'moun10_pro_theme_options[testimonial_section_enable]' )->value() );
}
/**
 * Check if testimonial section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_testimonial_section_content_page_enable( $control ) {
    $content_type = $control->manager->get_setting( 'moun10_pro_theme_options[testimonial_content_type]' )->value();
    return moun10_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if testimonial section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_testimonial_section_content_post_enable( $control ) {
    $content_type = $control->manager->get_setting( 'moun10_pro_theme_options[testimonial_content_type]' )->value();
    return moun10_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if testimonial section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_testimonial_section_content_category_enable( $control ) {
    $content_type = $control->manager->get_setting( 'moun10_pro_theme_options[testimonial_content_type]' )->value();
    return moun10_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[blog_content_type]' )->value();
	return moun10_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[blog_content_type]' )->value();
	return moun10_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[blog_content_type]' )->value();
	return moun10_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[blog_content_type]' )->value();
	return moun10_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if blog separator section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_blog_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'moun10_pro_theme_options[blog_content_type]' )->value();
    return moun10_pro_is_blog_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}
/**
 * Check if blog section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_if_subscription_enable( $control ) {
    return ( $control->manager->get_setting( 'moun10_pro_theme_options[subscription_section_enable]' )->value() );
}


/**
 * Check if team section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section seperator.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[team_content_type]' )->value();
	return moun10_pro_is_team_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[team_content_type]' )->value();
	return moun10_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[team_content_type]' )->value();
	return moun10_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[team_content_type]' )->value();
	return moun10_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[team_content_type]' )->value();
	return moun10_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}


/**
 * Check if counter section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[counter_section_enable]' )->value() );
}


/**
 * Check if features section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_features_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[features_section_enable]' )->value() );
}

/**
 * Check if features section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_features_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[features_content_type]' )->value();
	return moun10_pro_is_features_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if features section seperator.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_features_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[features_content_type]' )->value();
	return moun10_pro_is_features_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if features section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_features_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[features_content_type]' )->value();
	return moun10_pro_is_features_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if features section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_features_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[features_content_type]' )->value();
	return moun10_pro_is_features_section_enable( $control ) && ( 'category' == $content_type );
}


/*must_read section*/

/**
 * Check if must_read section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_must_read_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[must_read_section_enable]' )->value() );
}

/**
 * Check if must_read section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_must_read_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[must_read_content_type]' )->value();
	return moun10_pro_is_must_read_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if must_read section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_must_read_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[must_read_content_type]' )->value();
	return moun10_pro_is_must_read_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if must_read section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_must_read_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[must_read_content_type]' )->value();
	return moun10_pro_is_must_read_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[popular_destination_content_type]' )->value();
	return moun10_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular destination section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[popular_destination_content_type]' )->value();
	return moun10_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section content type is trip.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[popular_destination_content_type]' )->value();
	return moun10_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[popular_destination_content_type]' )->value();
	return moun10_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[popular_destination_content_type]' )->value();
	return moun10_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[popular_destination_content_type]' )->value();
	return moun10_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[popular_destination_content_type]' )->value();
	return moun10_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if package section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[package_section_enable]' )->value() );
}
/**
 * Check if package section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_package_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[package_content_type]' )->value();
	return moun10_pro_is_package_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if package section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_package_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[package_content_type]' )->value();
	return moun10_pro_is_package_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if package section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[package_content_type]' )->value();
	return moun10_pro_is_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if package section content type is trip.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_package_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[package_content_type]' )->value();
	return moun10_pro_is_package_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if package section content type is trip types.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[package_content_type]' )->value();
	return moun10_pro_is_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if package section content type is destination.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_package_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[package_content_type]' )->value();
	return moun10_pro_is_package_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if package section content type is activity.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_package_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[package_content_type]' )->value();
	return moun10_pro_is_package_section_enable( $control ) && ( 'activity' == $content_type );
}


/**
 * Check if offer section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_offer_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[offer_section_enable]' )->value() );
}
/**
 * Check if offer section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_offer_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[offer_content_type]' )->value();
	return moun10_pro_is_offer_section_enable( $control ) && ( 'post' == $content_type );
}

function moun10_pro_is_offer_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[offer_content_type]' )->value();
	return moun10_pro_is_offer_section_enable( $control ) && ( 'trip' == $content_type );
}


/**
 * Check if offer section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_offer_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[offer_content_type]' )->value();
	return moun10_pro_is_offer_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if offer section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_offer_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[offer_content_type]' )->value();
	return moun10_pro_is_offer_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if offer section content type is trip types.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_offer_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[offer_content_type]' )->value();
	return moun10_pro_is_offer_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if offer section content type is destination.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_offer_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[offer_content_type]' )->value();
	return moun10_pro_is_offer_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if offer section content type is activity.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_offer_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[offer_content_type]' )->value();
	return moun10_pro_is_offer_section_enable( $control ) && ( 'activity' == $content_type );
}


/**
 * Check if Recommended Package section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recommended_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[recommended_package_section_enable]' )->value() );
}

/**
 * Check if Recommended Package section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recommended_package_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[recommended_package_content_type]' )->value();
	return moun10_pro_is_recommended_package_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if Recommended Package section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recommended_package_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[recommended_package_content_type]' )->value();
	return moun10_pro_is_recommended_package_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if Recommended Package section content type is trip.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recommended_package_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[recommended_package_content_type]' )->value();
	return moun10_pro_is_recommended_package_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if Recommended Package section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recommended_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[recommended_package_content_type]' )->value();
	return moun10_pro_is_recommended_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if Recommended Package section content type is trip types.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recommended_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[recommended_package_content_type]' )->value();
	return moun10_pro_is_recommended_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if Recommended Package section content type is destination.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recommended_package_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[recommended_package_content_type]' )->value();
	return moun10_pro_is_recommended_package_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if Recommended Package section content type is activity.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recommended_package_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[recommended_package_content_type]' )->value();
	return moun10_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}


/**
 * Check if Featured Package section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[featured_package_section_enable]' )->value() );
}

/**
 * Check if Featured Package section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_package_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[featured_package_content_type]' )->value();
	return moun10_pro_is_featured_package_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if Featured Package section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_package_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[featured_package_content_type]' )->value();
	return moun10_pro_is_featured_package_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if Featured Package section content type is trip.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_package_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[featured_package_content_type]' )->value();
	return moun10_pro_is_featured_package_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if Featured Package section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[featured_package_content_type]' )->value();
	return moun10_pro_is_featured_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if Featured Package section content type is trip types.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[featured_package_content_type]' )->value();
	return moun10_pro_is_featured_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if Featured Package section content type is destination.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_package_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[featured_package_content_type]' )->value();
	return moun10_pro_is_featured_package_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if Featured Package section content type is activity.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_package_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[featured_package_content_type]' )->value();
	return moun10_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if call to action section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if call to action section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_cta_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[cta_content_type]' )->value();
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[cta_section_enable]' )->value() && ('trip' == $content_type) );
}
/**
 * Check if call to action section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[cta_content_type]' )->value();
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[cta_section_enable]' )->value() && ('post' == $content_type) );
}
/**
 * Check if call to action section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[cta_content_type]' )->value();
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[cta_section_enable]' )->value() && ('page' == $content_type) );
}

/*recent recent_product*/

/**
 * Check if recent_product section is enabled.
 *
 * @since Moun10 Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[recent_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if recent_product section content type is recent_product.
 *
 * @since Moun10 Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recent_product_section_content_recent_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[recent_product_content_type]' )->value();
	return moun10_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if recent_product section content type is recent_product category.
 *
 * @since Moun10 Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_recent_product_section_content_recent_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[recent_product_content_type]' )->value();
	return moun10_pro_is_recent_product_section_enable( $control ) && ( 'product-category' == $content_type );
}


/*recent featured_product*/

/**
 * Check if featured_product section is enabled.
 *
 * @since Moun10 Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[featured_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if featured_product section content type is featured_product.
 *
 * @since Moun10 Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_product_section_content_featured_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[featured_product_content_type]' )->value();
	return moun10_pro_is_featured_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if featured_product section content type is featured_product category.
 *
 * @since Moun10 Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_featured_product_section_content_featured_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[featured_product_content_type]' )->value();
	return moun10_pro_is_featured_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if course section is enabled.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'moun10_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is post.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[course_content_type]' )->value();
	return moun10_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[course_content_type]' )->value();
	return moun10_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since Moun10 Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function moun10_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'moun10_pro_theme_options[course_content_type]' )->value();
	return moun10_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}