<?php
/**
 * Package Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Package section
$wp_customize->add_section( 'moun10_pro_package_section', array(
	'title'             => esc_html__( 'Package','moun10-pro' ),
	'description'       => esc_html__( 'Package Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',

) );

// Package content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[package_section_enable]', array(
	'default'			=> 	$options['package_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[package_section_enable]', array(
	'label'             => esc_html__( 'Package Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_package_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[package_section_enable]', array(
		'selector'            => '#popular-packages .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[package_section_enable]',
    ) );
}

// Package post number  control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[package_count]', array(
	'default'          	=> $options['package_count'],
	'sanitize_callback' => 'moun10_pro_sanitize_number_range',
	'validate_callback' => 'moun10_pro_validate_package_count',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[package_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
	'section'           => 'moun10_pro_package_section',
	'active_callback'   => 'moun10_pro_is_package_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 4,
		'style' => 'width: 100px;'
		),
) );

// Package content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[package_content_type]', array(
	'default'          	=> $options['package_content_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_package_section_enable',
	'choices'			=> moun10_pro_package_content_type(),
) );

for ( $i=1; $i <= $options['package_count']; $i++ ) { 
	// package pages drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[package_content_page_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[package_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'moun10-pro' ), $i ),
		'section'           => 'moun10_pro_package_section',
		'choices'			=> moun10_pro_page_choices(),
		'active_callback'	=> 'moun10_pro_is_package_section_content_page_enable',
	) ) );

	// package posts drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[package_content_post_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[package_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'moun10-pro' ), $i ),
		'section'           => 'moun10_pro_package_section',
		'choices'			=> moun10_pro_post_choices(),
		'active_callback'	=> 'moun10_pro_is_package_section_content_post_enable',
	) ) );

	// package trips drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[package_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[package_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'moun10-pro' ), $i ),
		'section'           => 'moun10_pro_package_section',
		'choices'			=> moun10_pro_trip_choices(),
		'active_callback'	=> 'moun10_pro_is_package_section_content_trip_enable',
	) ) );
}
// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[package_content_category]', array(
	'sanitize_callback' => 'moun10_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[package_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'moun10-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
	'section'           => 'moun10_pro_package_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_package_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[package_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[package_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'moun10-pro' ),
	'section'           => 'moun10_pro_package_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_package_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[package_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[package_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'moun10-pro' ),
	'section'           => 'moun10_pro_package_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_package_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[package_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[package_content_destination]', array(
	'label'             => esc_html__( 'Select Destination', 'moun10-pro' ),
	'section'           => 'moun10_pro_package_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_package_section_content_destination_enable'
) ) );



// package button title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[package_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[package_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_package_section',
	'active_callback' 	=> 'moun10_pro_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[package_btn_label]', array(
		'selector'            => '#popular-packages div.entry-container .read-more a',
		'settings'            => 'moun10_pro_theme_options[package_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_package_btn_label_partial',
    ) );
}
