<?php

/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section('moun10_pro_testimonial_section', array(
    'title'         => esc_html__('Testimonials', 'moun10-pro'),
    'description'   => esc_html__('Testimonials Section options.', 'moun10-pro'),
    'panel'         => 'moun10_pro_front_page_panel',
));

// Testimonial content enable control and setting
$wp_customize->add_setting('moun10_pro_theme_options[testimonial_section_enable]', array(
    'default'           => $options['testimonial_section_enable'],
    'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
));

$wp_customize->add_control(new Moun10_Pro_Switch_Control($wp_customize, 'moun10_pro_theme_options[testimonial_section_enable]', array(
    'label'         => esc_html__('Testimonial Section Enable', 'moun10-pro'),
    'section'       => 'moun10_pro_testimonial_section',
    'on_off_label'  => moun10_pro_switch_options(),
)));

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[testimonial_section_enable]', array(
		'selector'            => '#testimonial .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[testimonial_section_enable]',
    ) );
}

// Testimonial section sub title control and setting
$wp_customize->add_setting('moun10_pro_theme_options[testimonial_section_sub_title]', array(
    'sanitize_callback'     => 'sanitize_text_field',
    'transport'             => 'postMessage',
    'default'               => $options['testimonial_section_sub_title'],
));

$wp_customize->add_control('moun10_pro_theme_options[testimonial_section_sub_title]', array(
    'label'             => esc_html__('Section Sub Title', 'moun10-pro'),
    'section'           => 'moun10_pro_testimonial_section',
    'type'              => 'text',
    'active_callback'   => 'moun10_pro_is_testimonial_section_enable',
));
$wp_customize->selective_refresh->add_partial('moun10_pro_theme_options[testimonial_section_sub_title]', array(
    'selector'          => '#testimonial .section-subtitle',
    'render_callback'   => 'moun10_pro_testimonial_section_partial_sub_title',
    )
);

// Testimonial section title control and setting
$wp_customize->add_setting('moun10_pro_theme_options[testimonial_section_title]', array(
    'default'               => $options['testimonial_section_title'],
    'sanitize_callback'     => 'sanitize_text_field',
    'transport'             => 'postMessage'
));

$wp_customize->add_control('moun10_pro_theme_options[testimonial_section_title]', array(
    'label'                 => esc_html__('Section Title', 'moun10-pro'),
    'section'               => 'moun10_pro_testimonial_section',
    'type'                  => 'text',
    'active_callback'       => 'moun10_pro_is_testimonial_section_enable',
));
$wp_customize->selective_refresh->add_partial('moun10_pro_theme_options[testimonial_section_title]', array(
        'selector'          => '#testimonial .section-title',
        'render_callback'   => 'moun10_pro_testimonial_section_partial_title',
    )
);

//Testimonial section content control type setting and control
$wp_customize->add_setting('moun10_pro_theme_options[testimonial_content_type]', array(
    'default'               => $options['testimonial_content_type'],
    'sanitize_callback'     => 'moun10_pro_sanitize_select',
));

$wp_customize->add_control('moun10_pro_theme_options[testimonial_content_type]', array(
    'label'                 => esc_html__('Content Type', 'moun10-pro'),
    'section'               => 'moun10_pro_testimonial_section',
    'type'                  => 'select',
    'active_callback'       => 'moun10_pro_is_testimonial_section_enable',
    'choices'               => array(
                                'page' => esc_html__('Page', 'moun10-pro'),
                                'post' => esc_html__('Post', 'moun10-pro'),
                                'category' => esc_html__('Category', 'moun10-pro'),
                            ),
));


// Testimonial post number control and setting
$wp_customize->add_setting('moun10_pro_theme_options[testimonial_posts_count]', array(
    'default'               => $options['testimonial_posts_count'],
    'sanitize_callback'     => 'absint',
));

$wp_customize->add_control('moun10_pro_theme_options[testimonial_posts_count]', array(
    'label'                 => esc_html__('Number of Posts', 'moun10-pro'),
    'description'           => esc_html__('Please input the number of of post to display and save. Then refresh the page to see the change.', 'moun10-pro'),
    'section'               => 'moun10_pro_testimonial_section',
    'active_callback'       => 'moun10_pro_is_testimonial_section_enable',
    'type'                  => 'number',
));

for ($i = 1; $i <= $options['testimonial_posts_count']; $i++):
// Testimonial pages drop down chooser control and setting
    $wp_customize->add_setting('moun10_pro_theme_options[testimonial_content_page_' . $i . ']', array(
        'sanitize_callback' => 'moun10_pro_sanitize_page',
    ));

    $wp_customize->add_control(new Moun10_Pro_Dropdown_Chooser($wp_customize, 'moun10_pro_theme_options[testimonial_content_page_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Page : %d', 'moun10-pro'), $i),
        'section'           => 'moun10_pro_testimonial_section',
        'choices'           => moun10_pro_page_choices(),
        'active_callback'   => 'moun10_pro_is_testimonial_section_content_page_enable',
    )));

    // Testimonial posts drop down chooser control and setting
    $wp_customize->add_setting('moun10_pro_theme_options[testimonial_content_post_' . $i . ']', array(
        'sanitize_callback' => 'moun10_pro_sanitize_page',
    ));

    $wp_customize->add_control(new Moun10_Pro_Dropdown_Chooser($wp_customize, 'moun10_pro_theme_options[testimonial_content_post_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Post : %d', 'moun10-pro'), $i),
        'section'           => 'moun10_pro_testimonial_section',
        'choices'           => moun10_pro_post_choices(),
        'active_callback'   => 'moun10_pro_is_testimonial_section_content_post_enable',
    )));
    // Testimonial posts sub title control and setting
    $wp_customize->add_setting('moun10_pro_theme_options[testimonial_post_sub_title_' . $i . ']', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));

    $wp_customize->add_control(new Moun10_Pro_Dropdown_Chooser($wp_customize, 'moun10_pro_theme_options[testimonial_post_sub_title_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Sub Title : %d', 'moun10-pro'), $i),
        'section'           => 'moun10_pro_testimonial_section',
        'active_callback'   => 'moun10_pro_is_testimonial_section_enable',
        'type'              => 'text',
    )));

    //testimonial separator
    $wp_customize->add_setting('moun10_pro_theme_options[testimonial_separator'. $i .']',array(
        'sanitize_callback'      => 'moun10_pro_sanitize_html',
    ));

    $wp_customize->add_control(new Moun10_Pro_Customize_Horizontal_Line($wp_customize,'moun10_pro_theme_options[testimonial_separator'. $i .']',array(
        'active_callback'       => 'moun10_pro_is_testimonial_section_enable',
        'type'                  =>'hr',
        'section'               =>'moun10_pro_testimonial_section',
    )));

endfor;

// Testimonial category drop down chooser control and setting
$wp_customize->add_setting('moun10_pro_theme_options[testimonial_category]', array(
    'sanitize_callback' => 'moun10_pro_sanitize_single_category',
));

$wp_customize->add_control(new Moun10_Pro_Dropdown_Taxonomies_Control($wp_customize, 'moun10_pro_theme_options[testimonial_category]', array(
    'label'             => esc_html__('Select Categories', 'moun10-pro'),
    'description'       => esc_html__('Note: Latest selected no of posts will be shown from selected category', 'moun10-pro'),
    'type'              => 'dropdown-taxonomies',
    'section'           => 'moun10_pro_testimonial_section',
    'active_callback'   => 'moun10_pro_is_testimonial_section_content_category_enable',
)));
