<?php
/**
 * Archive options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'moun10_pro_archive_section', array(
	'title'             => esc_html__( 'Blog/Archive','moun10-pro' ),
	'description'       => esc_html__( 'Archive section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_theme_options_panel',
) );

// Your latest posts title setting and control.
$wp_customize->add_setting( 'moun10_pro_theme_options[your_latest_posts_title]', array(
	'default'           => $options['your_latest_posts_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[your_latest_posts_title]', array(
	'label'             => esc_html__( 'Your Latest Posts Title', 'moun10-pro' ),
	'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'moun10-pro' ),
	'section'           => 'moun10_pro_archive_section',
	'type'				=> 'text',
	'active_callback'   => 'moun10_pro_is_latest_posts'
) );

// Archive date meta setting and control.
$wp_customize->add_setting( 'moun10_pro_theme_options[hide_date]', array(
	'default'           => $options['hide_date'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[hide_date]', array(
	'label'             => esc_html__( 'Hide Date', 'moun10-pro' ),
	'section'           => 'moun10_pro_archive_section',
	'on_off_label' 		=> moun10_pro_hide_options(),
) ) );

// Archive author category setting and control.
$wp_customize->add_setting( 'moun10_pro_theme_options[hide_category]', array(
	'default'           => $options['hide_category'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[hide_category]', array(
	'label'             => esc_html__( 'Hide Category', 'moun10-pro' ),
	'section'           => 'moun10_pro_archive_section',
	'on_off_label' 		=> moun10_pro_hide_options(),
) ) );

// Featured content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[blog_layout_design]', array(
	'default'          	=> $options['blog_layout_design'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
	//'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[blog_layout_design]', array(
	'label'             => esc_html__( 'Layout Design', 'moun10-pro' ),
	'section'           => 'moun10_pro_archive_section',
	'type'				=> 'select',
	'choices'			=> array(
		''      	=> esc_html__( 'Default Layout', 'moun10-pro' ),
		'list-view' => esc_html__( 'List View Layout', 'moun10-pro' ),
		'grid-view' => esc_html__( 'Grid View Layout', 'moun10-pro' ),
		),
) );

// features content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[blog_column]', array(
	'default'          	=> $options['blog_column'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
	//'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[blog_column]', array(
	'label'             => esc_html__( 'Column Layout', 'moun10-pro' ),
	'section'           => 'moun10_pro_archive_section',
	'type'				=> 'select',
	'choices'			=> array( 
		'col-1'		=> esc_html__( 'One Column', 'moun10-pro' ),
		'col-2'		=> esc_html__( 'Two Column', 'moun10-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'moun10-pro' ),
	),
) );

// read more text setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[read_more_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['read_more_text'],
) );

$wp_customize->add_control( 'moun10_pro_theme_options[read_more_text]', array(
	'label'           	=> esc_html__( 'Read More Text Label', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_archive_section',
	'type'				=> 'text',
) );

