<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function moun10_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'moun10-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function moun10_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'moun10-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function moun10_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'moun10-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function moun10_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'moun10-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function moun10_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'moun10-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'moun10_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function moun10_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'moun10-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'moun10-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'moun10-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'moun10-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'moun10-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'moun10-pro' ),
        );

        $output = apply_filters( 'moun10_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'moun10_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function moun10_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'moun10-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'moun10-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'moun10-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'moun10-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'moun10-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'moun10-pro' ),
        );

        $output = apply_filters( 'moun10_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'moun10_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function moun10_pro_site_layout() {
        $moun10_pro_site_layout = array(
            'wide'          => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout'  => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout'  => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'moun10_pro_site_layout', $moun10_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'moun10_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function moun10_pro_selected_sidebar() {
        $moun10_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'moun10-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'moun10-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'moun10-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'moun10-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'moun10-pro' ),
        );

        $output = apply_filters( 'moun10_pro_selected_sidebar', $moun10_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'moun10_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function moun10_pro_global_sidebar_position() {
        $moun10_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'moun10_pro_global_sidebar_position', $moun10_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'moun10_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function moun10_pro_sidebar_position() {
        $moun10_pro_sidebar_position = array(
            'right-sidebar'         => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'          => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'            => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'    => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'moun10_pro_sidebar_position', $moun10_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'moun10_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function moun10_pro_pagination_options() {
        $moun10_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'moun10-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'moun10-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'moun10-pro' ),
        );

        $output = apply_filters( 'moun10_pro_pagination_options', $moun10_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'moun10_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function moun10_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'moun10-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'moun10-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'moun10-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'moun10-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'moun10-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'moun10-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'moun10-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'moun10-pro' ),
        );
        return apply_filters( 'moun10_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'moun10_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function moun10_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'moun10-pro' ),
            'off'       => esc_html__( 'Disable', 'moun10-pro' )
        );
        return apply_filters( 'moun10_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'moun10_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function moun10_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'moun10-pro' ),
            'off'       => esc_html__( 'No', 'moun10-pro' )
        );
        return apply_filters( 'moun10_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'moun10_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function moun10_pro_sortable_sections() {
        $options = moun10_pro_get_theme_options();
        $sections = array();
        if ( $options['home_layout'] == 'default-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'moun10-pro' ),
                'trip_search'           => esc_html__( 'Trip Search', 'moun10-pro' ),
                'about'                 => esc_html__( 'About us', 'moun10-pro' ),
                'popular_destination'   => esc_html__( 'Popular Destination', 'moun10-pro' ),
                'featured_product'      => esc_html__( 'Featured Product', 'moun10-pro' ),
                'features'              => esc_html__( 'Features', 'moun10-pro' ),
                'service'               => esc_html__( 'Service', 'moun10-pro' ),
                'package'               => esc_html__( 'Package', 'moun10-pro' ),
                'cta'                   => esc_html__( 'Call TO Action', 'moun10-pro' ),
                'featured_package'      => esc_html__( 'Featured Package', 'moun10-pro' ),
                'recent_product'        => esc_html__( 'Recent Product', 'moun10-pro' ),
                'counter'               => esc_html__( 'Counter', 'moun10-pro' ),
                'must_read'             => esc_html__( 'Must Read', 'moun10-pro' ),
                'team'                  => esc_html__( 'Team', 'moun10-pro' ),
                'offer'                 => esc_html__( 'Offer', 'moun10-pro' ),
                'recommended_package'   => esc_html__( 'Recommended Packages', 'moun10-pro' ),
                'destination'           => esc_html__( 'Destination', 'moun10-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'moun10-pro' ),
                'blog'                  => esc_html__( 'Blog', 'moun10-pro' ),
                'course'                => esc_html__( 'Course', 'moun10-pro' ),
                'subscription'          => esc_html__( 'Subscription', 'moun10-pro' ),

            );
        }
        if ( $options['home_layout'] == 'second-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'moun10-pro' ),
                'about'                 => esc_html__( 'About us', 'moun10-pro' ),
                'service'               => esc_html__( 'Service', 'moun10-pro' ),
                'destination'           => esc_html__( 'Destination', 'moun10-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'moun10-pro' ),
                'blog'                  => esc_html__( 'Blog', 'moun10-pro' ),
                'subscription'          => esc_html__( 'Subscription', 'moun10-pro' ),

            );
        }
        if ( $options['home_layout'] == 'third-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'moun10-pro' ),
                'about'                 => esc_html__( 'About us', 'moun10-pro' ),
                'service'               => esc_html__( 'Service', 'moun10-pro' ),
                'destination'           => esc_html__( 'Destination', 'moun10-pro' ),
                'subscription'          => esc_html__( 'Subscription', 'moun10-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'moun10-pro' ),
                'blog'                  => esc_html__( 'Blog', 'moun10-pro' ),

            );
        }
        if ( $options['home_layout'] == 'fourth-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'moun10-pro' ),
                'about'                 => esc_html__( 'About us', 'moun10-pro' ),
                'featured_product'      => esc_html__( 'Featured Product', 'moun10-pro' ),
                'cta'                   => esc_html__( 'Call TO Action', 'moun10-pro' ),
                'recent_product'        => esc_html__( 'Recent Product', 'moun10-pro' ),
                'destination'           => esc_html__( 'Destination', 'moun10-pro' ),
                'features'              => esc_html__( 'Features', 'moun10-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'moun10-pro' ),
                'blog'                  => esc_html__( 'Blog', 'moun10-pro' ),                
                'subscription'          => esc_html__( 'Subscription', 'moun10-pro' ),

            );
        }
        if ( $options['home_layout'] == 'fifth-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'moun10-pro' ),
                'features'              => esc_html__( 'Features', 'moun10-pro' ),
                'about'                 => esc_html__( 'About us', 'moun10-pro' ),
                'team'                  => esc_html__( 'Team', 'moun10-pro' ),
                'counter'               => esc_html__( 'Counter', 'moun10-pro' ),
                'course'                => esc_html__( 'Course', 'moun10-pro' ),
                'destination'           => esc_html__( 'Destination', 'moun10-pro' ),
                'subscription'          => esc_html__( 'Subscription', 'moun10-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'moun10-pro' ),
                'blog'                  => esc_html__( 'Blog', 'moun10-pro' ),
                
            );
        }
        if ( $options['home_layout'] == 'sixth-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'moun10-pro' ),
                'features'              => esc_html__( 'Features', 'moun10-pro' ),
                'about'                 => esc_html__( 'About us', 'moun10-pro' ),
                'must_read'             => esc_html__( 'Must Read', 'moun10-pro' ),
                'team'                  => esc_html__( 'Team', 'moun10-pro' ),
                'counter'               => esc_html__( 'Counter', 'moun10-pro' ),
                'destination'           => esc_html__( 'Destination', 'moun10-pro' ),
                'subscription'          => esc_html__( 'Subscription', 'moun10-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'moun10-pro' ),
                'blog'                  => esc_html__( 'Blog', 'moun10-pro' ),
                
            );
        }
        if ( $options['home_layout'] == 'seventh-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'moun10-pro' ),
                'about'                 => esc_html__( 'About us', 'moun10-pro' ),
                'service'               => esc_html__( 'Service', 'moun10-pro' ),
                'destination'           => esc_html__( 'Destination', 'moun10-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'moun10-pro' ),
                'blog'                  => esc_html__( 'Blog', 'moun10-pro' ),
                'subscription'          => esc_html__( 'Subscription', 'moun10-pro' ),
                
            );
        }
        return apply_filters( 'moun10_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'moun10_pro_popular_destination_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function moun10_pro_popular_destination_content_type() {
        $moun10_pro_popular_destination_content_type = array(
            'page'      => esc_html__( 'Page', 'moun10-pro' ),
            'post'      => esc_html__( 'Post', 'moun10-pro' ),
            'category'  => esc_html__( 'Category', 'moun10-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $moun10_pro_popular_destination_content_type = array_merge( $moun10_pro_popular_destination_content_type, array(
                'trip'          => esc_html__( 'Trip', 'moun10-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'moun10-pro' ),
                'destination'   => esc_html__( 'Destination', 'moun10-pro' ),
                'activity'      => esc_html__( 'Activity', 'moun10-pro' ),
                ) );
        }

        $output = apply_filters( 'moun10_pro_popular_destination_content_type', $moun10_pro_popular_destination_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'moun10_pro_package_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function moun10_pro_package_content_type() {
        $moun10_pro_package_content_type = array(
            'page'      => esc_html__( 'Page', 'moun10-pro' ),
            'post'      => esc_html__( 'Post', 'moun10-pro' ),
            'category'  => esc_html__( 'Category', 'moun10-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $moun10_pro_package_content_type = array_merge( $moun10_pro_package_content_type, array(
                'trip'          => esc_html__( 'Trip', 'moun10-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'moun10-pro' ),
                'destination'   => esc_html__( 'Destination', 'moun10-pro' ),
                'activity'      => esc_html__( 'Activity', 'moun10-pro' ),
                ) );
        }

        $output = apply_filters( 'moun10_pro_package_content_type', $moun10_pro_package_content_type );


        return $output;
    }
endif;


if ( ! function_exists( 'moun10_pro_offer_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function moun10_pro_offer_content_type() {
        $moun10_pro_offer_content_type = array(
            'page'      => esc_html__( 'Page', 'moun10-pro' ),
            'post'      => esc_html__( 'Post', 'moun10-pro' ),
            'category'  => esc_html__( 'Category', 'moun10-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $moun10_pro_offer_content_type = array_merge( $moun10_pro_offer_content_type, array(
                'trip'          => esc_html__( 'Trip', 'moun10-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'moun10-pro' ),
                'destination'   => esc_html__( 'Destination', 'moun10-pro' ),
                'activity'      => esc_html__( 'Activity', 'moun10-pro' ),
                ) );
        }

        $output = apply_filters( 'moun10_pro_offer_content_type', $moun10_pro_offer_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'moun10_pro_recommended_package_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function moun10_pro_recommended_package_content_type() {
        $moun10_pro_recommended_package_content_type = array(
            'page'      => esc_html__( 'Page', 'moun10-pro' ),
            'post'      => esc_html__( 'Post', 'moun10-pro' ),
            'category'  => esc_html__( 'Category', 'moun10-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $moun10_pro_recommended_package_content_type = array_merge( $moun10_pro_recommended_package_content_type, array(
                'trip'          => esc_html__( 'Trip', 'moun10-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'moun10-pro' ),
                'destination'   => esc_html__( 'Destination', 'moun10-pro' ),
                'activity'      => esc_html__( 'Activity', 'moun10-pro' ),
                ) );
        }

        $output = apply_filters( 'moun10_pro_recommended_package_content_type', $moun10_pro_recommended_package_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'moun10_pro_featured_package_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function moun10_pro_featured_package_content_type() {
        $moun10_pro_featured_package_content_type = array(
            'category'  => esc_html__( 'Category', 'moun10-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $moun10_pro_featured_package_content_type = array_merge( $moun10_pro_featured_package_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'moun10-pro' ),
                'destination'   => esc_html__( 'Destination', 'moun10-pro' ),
                'activity'      => esc_html__( 'Activity', 'moun10-pro' ),
                ) );
        }

        $output = apply_filters( 'moun10_pro_featured_package_content_type', $moun10_pro_featured_package_content_type );


        return $output;
    }
endif;


if ( ! function_exists( 'moun10_pro_cta_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function moun10_pro_cta_content_type() {
        $moun10_pro_cta_content_type = array(
            'page'      => esc_html__( 'Page', 'moun10-pro' ),
            'post'      => esc_html__( 'Post', 'moun10-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $moun10_pro_cta_content_type = array_merge( $moun10_pro_cta_content_type, array(
                'trip'          => esc_html__( 'Trip', 'moun10-pro' ),
                ) );
        }

        $output = apply_filters( 'moun10_pro_cta_content_type', $moun10_pro_cta_content_type );


        return $output;
    }
endif;


if ( ! function_exists( 'moun10_pro_featured_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function moun10_pro_featured_product_content_type() {
        $moun10_pro_featured_product_content_type = array(
            'product'   => esc_html__( 'Product', 'moun10-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'moun10-pro' ),
        );

        $output = apply_filters( 'moun10_pro_featured_product_content_type', $moun10_pro_featured_product_content_type );

        return $output;
    }
endif;


if ( ! function_exists( 'moun10_pro_recent_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function moun10_pro_recent_product_content_type() {
        $moun10_pro_recent_product_content_type = array(
            'product'   => esc_html__( 'Product', 'moun10-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'moun10-pro' ),
        );

        $output = apply_filters( 'moun10_pro_recent_product_content_type', $moun10_pro_recent_product_content_type );

        return $output;
    }
endif;