<?php
/**
 * Features section
 *
 * This is the template for the content of features section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_features_section' ) ) :
    /**
    * Add features section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_features_section() {
    	$options = moun10_pro_get_theme_options();
        // Check if features is enabled on frontpage
        $features_enable = apply_filters( 'moun10_pro_section_status', true, 'features_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'fourth-design', 'fifth-design', 'sixth-design' ) ) ) {
            $features_enable = false;
        }

        if ( true !== $features_enable ) {
            return false;
        }
        // Get features section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_features_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render features section now.
        moun10_pro_render_features_section( $section_details );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_features_section_details' ) ) :
    /**
    * features section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input features section details.
    */
    function moun10_pro_get_features_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        // Content type.
        $features_content_type  = $options['features_content_type'];
        $features_count = ! empty( $options['features_count'] ) ? $options['features_count'] : 3;
        
        $content = array();
        switch ( $features_content_type ) {
        	
            case 'page':
                $page_ids = array();
                $icons = array();

                for ( $i = 1; $i <= $features_count; $i++ ) {
                    if ( ! empty( $options['features_content_page_' . $i] ) ) :
                        $page_ids[] = $options['features_content_page_' . $i];
                        $icons[] = ! empty( $options['features_content_icon_' . $i] ) ? $options['features_content_icon_' . $i] : 'fa-laptop';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $features_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $icons = array();

                for ( $i = 1; $i <= $features_count; $i++ ) {
                    if ( ! empty( $options['features_content_post_' . $i] ) ) :
                        $post_ids[] = $options['features_content_post_' . $i];
                        $icons[] = ! empty( $options['features_content_icon_' . $i] ) ? $options['features_content_icon_' . $i] : 'fa-laptop';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $features_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['features_content_category'] ) ? $options['features_content_category'] : '';
                $icons = array();
                
                for ( $i = 1; $i <= $features_count; $i++ ) {
                    $icons[] = ! empty( $options['features_content_icon_' . $i] ) ? $options['features_content_icon_' . $i] : 'fa-laptop';
                }

                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $features_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $i = 0;
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = moun10_pro_trim_content( 20);
                    $page_post['icon']      = ! empty( $icons[ $i ] ) ? $icons[ $i ] : 'fa-laptop';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// features section content details.
add_filter( 'moun10_pro_filter_features_section_details', 'moun10_pro_get_features_section_details' );


if ( ! function_exists( 'moun10_pro_render_features_section' ) ) :
  /**
   * Start features section
   *
   * @return string features content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_features_section( $content_details = array() ) {
        $options = moun10_pro_get_theme_options();
        $column = ! empty( $options['features_column'] ) ? $options['features_column'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="moun10_pro_features_section">
            <?php if($options['home_layout'] == 'fourth-design'): ?>
            <div id="business-services-section" class="business-services relative">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                      <?php moun10_pro_section_tooltip( 'business-services-class' ); ?>
                  <?php endif ?>
                    <div class="business-section-header">
                    <?php if( !empty( $options['features_title'] ) ): ?>
                        <h2 class="business-section-title"><?php echo esc_html( $options['features_title'] ); ?></h2>
                    <?php endif;
                    if( !empty( $options['features_description'] ) ):
                     ?>
                        <p class="business-section-subtitle"><?php echo esc_html( $options['features_description'] ); ?></p>
                    <?php endif; ?>
                    </div>
                    <div class="business-section-content <?php echo esc_attr( $column ); ?> clear">
                    <?php foreach ( $content_details as $i=>$content ) : ?>

                        <article>
                            <div class="service-item-wrapper">
                                <div class="service-icon">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><i class="fa <?php echo esc_attr( $content['icon'] ); ?>"></i></a>
                                </div><!-- .service-icon -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </header>
                                </div><!-- .entry-container -->
                            </div><!-- .service-item-wrapper -->
                        </article>
                    <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>
        <?php else: ?>

            <div id="business-services" class="business-services relative page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                      <?php moun10_pro_section_tooltip( 'business-services-class' ); ?>
                  <?php endif ?>
                <?php if( $options['home_layout'] == 'fifth-design' ){ ?>

                    <div class="business-section-header">
                    <?php if( !empty( $options['features_title'] ) ): ?>
                        <h2 class="business-section-title"><?php echo esc_html( $options['features_title'] ); ?></h2>
                    <?php endif;
                    if( !empty( $options['features_description'] ) ):
                     ?>
                        <p class="business-section-subtitle"><?php echo esc_html( $options['features_description'] ); ?></p>
                    <?php endif; ?>
                    </div>

                    <?php }else{ ?>
                        <div class="business-section-header">
                            <?php  if( !empty( $options['features_description'] ) ):
                             ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['features_description'] ); ?></p>
                            <?php endif;

                            if( !empty( $options['features_title'] ) ): ?>
                                <h2 class="section-title"><?php echo esc_html( $options['features_title'] ); ?></h2>
                            <?php endif;  ?>
                       
                        </div>
                   <?php } ?>

                    <div class="business-section-content <?php echo esc_attr( $column ); ?> clear">
                        
                    
                        <?php foreach ( $content_details as $content ) : ?>

                            <article>
                                <div class="business-service-item">
                                    <div class="business-service-icon">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><i class="fa <?php echo esc_attr( $content['icon'] ); ?>"></i></a>
                                    </div><!-- .business-service-icon -->

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .business-service-item -->
                            </article>
                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #business-services-section -->

        <?php endif; ?>
        </div>
        
<?php }
endif;