<?php
/**
 * Must Read section
 *
 * This is the template for the content of must_read section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_must_read_section' ) ) :
    /**
    * Add must_read section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_must_read_section() {
    	$options = moun10_pro_get_theme_options();
        // Check if must_read is enabled on frontpage
        $must_read_enable = apply_filters( 'moun10_pro_section_status', true, 'must_read_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'sixth-design' ) ) ) {
            $must_read_enable = false;
        }

        if ( true !== $must_read_enable ) {
            return false;
        }
        // Get must_read section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_must_read_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render must_read section now.
        moun10_pro_render_must_read_section( $section_details );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_must_read_section_details' ) ) :
    /**
    * must_read section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input must_read section details.
    */
    function moun10_pro_get_must_read_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        // Content type.
        $must_read_content_type  = $options['must_read_content_type'];
        $must_read_count = ! empty( $options['must_read_count'] ) ? $options['must_read_count'] : 3;
        
        $content = array();
        switch ( $must_read_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $must_read_count; $i++ ) {
                    if ( ! empty( $options['must_read_content_page_' . $i] ) )
                        $page_ids[] = $options['must_read_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $must_read_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $must_read_count; $i++ ) {
                    if ( ! empty( $options['must_read_content_post_' . $i] ) )
                        $post_ids[] = $options['must_read_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $must_read_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['must_read_content_category'] ) ? $options['must_read_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $must_read_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = moun10_pro_trim_content( 20 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// must_read section content details.
add_filter( 'moun10_pro_filter_must_read_section_details', 'moun10_pro_get_must_read_section_details' );


if ( ! function_exists( 'moun10_pro_render_must_read_section' ) ) :
  /**
   * Start must_read section
   *
   * @return string must_read content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_must_read_section( $content_details = array() ) {
        $options = moun10_pro_get_theme_options();
        $must_read_content_type  = $options['must_read_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="moun10_pro_must_read_section">
            <div id="must-read" class="page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                          <?php moun10_pro_section_tooltip( 'must-read' ); ?>
                      <?php endif ?>
                    <div class="business-section-header">
                        <?php if( !empty( $options['must_read_title'] || !empty($options['must_read_sub_title'])) ):
                            if(!empty($options['must_read_sub_title'])) echo sprintf( '<p class="section-subtitle">%s</p>',  esc_html( $options['must_read_sub_title'] ) ); 
                            if(!empty($options['must_read_title'])) echo sprintf( '<h2 class="section-title">%s</h2>',  esc_html( $options['must_read_title'] ) ); ?>
                        <?php endif; ?>
                    </div><!-- .business-section-header -->

                    <div class="business-section-content col-3">
                        <?php foreach ( $content_details as $content ) : ?>

                            <article class="hentry">
                                <div class="must-read-wrapper">
                                    <?php if( !empty( $content['image'] ) ): ?>
                                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="featured-image-link"></a>
                                        </div><!-- .featured-image -->
                                    <?php endif; ?>

                                    <div class="entry-container">
                                        <div class="entry-meta">
                                            <span class="cat-links">
                                                <?php the_category( ' ', '', $content['id'] ); ?>
                                            </span>
                                        </div><!-- .entry-meta -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <P><?php echo wp_kses_post( $content['excerpt'] ); ?></P>
                                        </div>

                                        <?php if(!empty($options['must_read_btn_title'])) :?>
                                            <div class="business-read-more">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['must_read_btn_title'] )?></a>
                                            </div>
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .must-read-wrapper -->
                            </article>
                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>
        </div>
        
    <?php 
    }    
endif;