<?php
/**
 * Package section
 *
 * This is the template for the content of Package section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_package_section' ) ) :
    /**
    * Add Package section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_package_section() {
        $options = moun10_pro_get_theme_options();
        
        // Check if Package is enabled on frontpage
        $package_enable = apply_filters( 'moun10_pro_section_status', true, 'package_section_enable' );

         if ( !in_array( $options['home_layout'], array( 'default-design' ) ) ) {
            $package_enable = false;
        }

        if ( true !== $package_enable ) {
            return false;
        }
        // Get Package section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_package_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Package section now.
        moun10_pro_render_package_section( $section_details );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_package_section_details' ) ) :
    /**
    * Package section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input Package section details.
    */
    function moun10_pro_get_package_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        $package_count  = $options['package_count']; // Pakage Content Type
        $package_content_type  = $options['package_content_type']; // Package Post Count

        $content = array();
        $args = array();
        switch ( $package_content_type ) {
            case 'page':
				$page_ids = array();

				for ( $i = 1; $i <= $package_count; $i++ ) {
					if ( ! empty( $options['package_content_page_' . $i] ) )
						$page_ids[] = $options['package_content_page_' . $i];
				}
				
				$args = array(
					'post_type'         => 'page',
					'post__in'          => ( array ) $page_ids,
					'posts_per_page'    => absint( $package_count ),
					'orderby'           => 'post__in',
					);                    
			break;

			case 'post':
				$post_ids = array();

				for ( $i = 1; $i <= $package_count; $i++ ) {
					if ( ! empty( $options['package_content_post_' . $i] ) )
						$post_ids[] = $options['package_content_post_' . $i];
				}
				$args = array(
					'post_type'             => 'post',
					'post__in'              => ( array ) $post_ids,
					'posts_per_page'        => absint( $package_count ),
					'orderby'               => 'post__in',
					'ignore_sticky_posts'   => true,
					);                    
			break;
        	
            case 'category':
                $cat_ids = ! empty( $options['package_content_category'] ) ? $options['package_content_category'] : '';

                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint($package_count),
                    'cat'                   =>  absint($cat_ids),
                    'ignore_sticky_posts'   => true,
                    );
            break;
            
            case 'trip':
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$page_ids = array();

				for ( $i = 1; $i <= $package_count; $i++ ) {
					if ( ! empty( $options['package_content_trip_' . $i] ) )
						$page_ids[] = $options['package_content_trip_' . $i];
				}
				
				$args = array(
					'post_type'         => 'itineraries',
					'post__in'          => ( array ) $page_ids,
					'posts_per_page'    => absint( $package_count ),
					'orderby'           => 'post__in',
					);   

				$content['taxonomy'] = 'travel_locations';

			break;

            case 'trip-types': // trip-types
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = ! empty( $options['package_content_trip_types'] ) ? $options['package_content_trip_types'] : '';

                if ( empty( $cat_ids ) )
                    return;

                $args = array(
                    'post_type' => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_ids,
                        ),
                    ),
                    'posts_per_page'  =>absint($package_count),
                    );
                $content['taxonomy'] = 'itinerary_types';

            break;

            case 'destination':  //Destination
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                $cat_ids = ! empty( $options['package_content_destination'] ) ? $options['package_content_destination'] : '';
                if ( empty( $cat_ids ) )
                    return;

                $args = array(
                    'post_type' => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_ids,
                        ),
                    ),
                    'posts_per_page'  => absint($package_count),
                    ); 
                $content['taxonomy'] = 'travel_locations';

            break;

            case 'activity': //Activity
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_ids = ! empty( $options['package_content_activity'] ) ? $options['package_content_activity'] :'';

                if ( empty( $cat_ids ) )
                    return;

                $args = array(
                    'post_type' => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_ids,
                        ),
                    ),
                    'posts_per_page'  =>absint($package_count),
                    ); 
                $content['taxonomy'] = 'activity';

            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
		$content['details'] = array();
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = moun10_pro_trim_content(30);
                $page_post['url']       = get_the_permalink();
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) :  get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;    

// Package section content details.
add_filter( 'moun10_pro_filter_package_section_details', 'moun10_pro_get_package_section_details' );


if ( ! function_exists( 'moun10_pro_render_package_section' ) ) :
  /**
   * Start Package section
   *
   * @return string Package content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_package_section( $content_details = array() ) {
        $options                = moun10_pro_get_theme_options();
        $taxonomy               = isset($content_details['taxonomy']) ? $content_details['taxonomy'] : 'category';
        $package_content_type   = $options['package_content_type'];
        $package_btn_label      = $options['package_btn_label'];
        $enable_sale            = NULL;
        if ( empty( $content_details ) ) {
           return;
        } ?>
        <div id="moun10_pro_package_section">
             <div id="popular-packages" class="relative page-section">
            <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                      <?php moun10_pro_section_tooltip( 'popular-packages' ); ?>
                  <?php endif ?>
                <div class="section-content clear">
                <?php 
                foreach ($content_details['details'] as $content):

                    if ( ! in_array( $package_content_type, array( 'category', 'page', 'post' ) ) ) :
                        $enable_sale     = get_post_meta( $content['id'], 'wp_travel_enable_sale', true );
                        $regular_price   = absint(WP_Travel_Helpers_Pricings::get_price( array( 'trip_id'=> $content['id'], 'is_regular_price'=>true )));
                        $enable_sale     = WP_Travel_Helpers_Trips::is_sale_enabled( array( 'trip_id' => $content['id']) );
                        $sale_price      = WP_Travel_Helpers_Pricings::get_price( array( 'trip_id'=> $content['id'] ) );
                        $settings        = wptravel_get_settings();
                        $currency_code   = ( isset( $settings['currency'] ) ) ? $settings['currency'] : '';
                        $currency_symbol = wptravel_get_currency_symbol( $currency_code );
                        $group_size      = get_post_meta( $content['id'], 'wp_travel_group_size', true );

                        if($regular_price != 0)
                            $save_percent = (($regular_price - $sale_price)/$regular_price)*100;
                        endif;
                        
                        $terms           =  get_the_terms( $content['id'],$taxonomy); ?>
            
                    <article class="has-post-thumbnail">
                        <div class="featured-image" style="background-image: url(<?php echo esc_url($content['image'])?>);">

                            <?php if($enable_sale ): ?>
                            <span class="package-offer"><span><?php esc_html_e('save', 'moun10-pro')?></span><?php echo round($save_percent,1); ?>%</span>
                            <?php endif; ?>

                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <header class="entry-header">

                        <?php if( ! empty( $terms ) && ! is_wp_error( $terms ) ) : ?>
                            <p class="subtitle"><?php echo esc_html($terms[0]->name); ?></p>
                        <?php endif; ?>

                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                            </header>

                            <?php if ( ! in_array( $package_content_type, array( 'category', 'page', 'post' ) ) && class_exists('WP_Travel')  ) :  ?>
                                <div class="entry-meta">
                                    <div class="trip-pax">
                                        <?php echo moun10_pro_get_svg(array('icon'=>'user')) ;
                                        !empty($group_size) ? printf( apply_filters( 'wp_travel_template_group_size_text',__( '%d %s', 'moun10-pro' ) ), esc_html( $group_size ), esc_html__('People', 'moun10-pro')) :  esc_html_e('N/A','moun10-pro') ;?>
                                    </div><!-- .trip-pax -->

                                    <div class="trip-date">
                                        <?php
                                        wptravel_get_trip_duration( $content['id'] ); ?>
                                    </div><!-- .trip-date -->

                                    <div class="trip-price">
                                    <?php
                                        if($enable_sale): ?>
                                        <del>
                                            <span>          
                                                <span class="wp-travel-trip-currency"><?php echo esc_html($currency_symbol); ?></span><span class="wp-travel-trip-price-figure"><?php echo esc_html($regular_price); ?></span>
                                            </span>
                                        </del>
                                        <?php endif; ?>
                                        <ins>
                                            <span>          
                                                <span class="wp-travel-trip-currency"><?php echo esc_html($currency_symbol); ?></span><span class="wp-travel-trip-price-figure"><?php echo esc_html($sale_price); ?></span>
                                            </span>
                                        </ins>
                                    </div><!-- .trip-price -->
                                </div><!-- .entry-meta -->  
                            <?php endif; ?>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                            </div><!-- .enrty-content -->

                            <?php if(!empty($package_btn_label)): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($package_btn_label); ?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>
                
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #popular-packages -->
        </div>
       
        
    <?php }
endif;