<?php
/**
 * Recommended Packages section
 *
 * This is the template for the content of Recommended Packages section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_recommended_package_section' ) ) :
    /**
    * Add Recommended Packages section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_recommended_package_section() {
        $options = moun10_pro_get_theme_options();
        
        // Check if Recommended Packages is enabled on frontpage
        $recommended_package_enable = apply_filters( 'moun10_pro_section_status', true, 'recommended_package_section_enable' );

         if ( !in_array( $options['home_layout'], array( 'default-design' ) ) ) {
            $recommended_package_enable = false;
        }

        if ( true !== $recommended_package_enable ) {
            return false;
        }
        // Get Recommended Packages section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_recommended_package_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Recommended Packages section now.
        moun10_pro_render_recommended_package_section( $section_details );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_recommended_package_section_details' ) ) :
    /**
    * Recommended Packages section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input Recommended Packages section details.
    */
    function moun10_pro_get_recommended_package_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        $recommended_package_count  = $options['recommended_package_count']; // Pakage Content Type
        $recommended_package_content_type  = $options['recommended_package_content_type']; // Recommended Packages Post Count

        $content = array();
        $args = array();
        switch ( $recommended_package_content_type ) {
            case 'page':
				$page_ids = array();

				for ( $i = 1; $i <= $recommended_package_count; $i++ ) {
					if ( ! empty( $options['recommended_package_content_page_' . $i] ) )
						$page_ids[] = $options['recommended_package_content_page_' . $i];
				}
				
				$args = array(
					'post_type'         => 'page',
					'post__in'          => ( array ) $page_ids,
					'posts_per_page'    => absint( $recommended_package_count ),
					'orderby'           => 'post__in',
					);                    
			break;

			case 'post':
				$post_ids = array();

				for ( $i = 1; $i <= $recommended_package_count; $i++ ) {
					if ( ! empty( $options['recommended_package_content_post_' . $i] ) )
						$post_ids[] = $options['recommended_package_content_post_' . $i];
				}
				$args = array(
					'post_type'             => 'post',
					'post__in'              => ( array ) $post_ids,
					'posts_per_page'        => absint( $recommended_package_count ),
					'orderby'               => 'post__in',
					'ignore_sticky_posts'   => true,
					);                    
			break;
        	
            case 'category':
                $cat_ids = ! empty( $options['recommended_package_content_category'] ) ? $options['recommended_package_content_category'] : '';

                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint($recommended_package_count),
                    'cat'                   =>  absint($cat_ids),
                    'ignore_sticky_posts'   => true,
                    );
            break;

                        
            case 'trip':
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$page_ids = array();

				for ( $i = 1; $i <= $recommended_package_count; $i++ ) {
					if ( ! empty( $options['recommended_package_content_trip_' . $i] ) )
						$page_ids[] = $options['recommended_package_content_trip_' . $i];
				}
				
				$args = array(
					'post_type'         => 'itineraries',
					'post__in'          => ( array ) $page_ids,
					'posts_per_page'    => absint( $recommended_package_count ),
					'orderby'           => 'post__in',
					);   

				$content['taxonomy'] = 'travel_locations';

			break;

            case 'trip-types': // trip-types
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = ! empty( $options['recommended_package_content_trip_types'] ) ? $options['recommended_package_content_trip_types'] : '';

                if ( empty( $cat_ids ) )
                    return;

                $args = array(
                    'post_type' => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_ids,
                        ),
                    ),
                    'posts_per_page'  =>absint($recommended_package_count),
                    );
                $content['taxonomy'] = 'itinerary_types';

            break;

            case 'destination':  //Destination
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                $cat_ids = ! empty( $options['recommended_package_content_destination'] ) ? $options['recommended_package_content_destination'] : '';
                if ( empty( $cat_ids ) )
                    return;

                $args = array(
                    'post_type' => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_ids,
                        ),
                    ),
                    'posts_per_page'  => absint($recommended_package_count),
                    ); 
                $content['taxonomy'] = 'travel_locations';

            break;

            case 'activity': //Activity
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_ids = ! empty( $options['recommended_package_content_activity'] ) ? $options['recommended_package_content_activity'] :'';

                if ( empty( $cat_ids ) )
                    return;

                $args = array(
                    'post_type' => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_ids,
                        ),
                    ),
                    'posts_per_page'  =>absint($recommended_package_count),
                    ); 
                $content['taxonomy'] = 'activity';

            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
		$content['details'] = array();
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = moun10_pro_trim_content(30);
                $page_post['url']       = get_the_permalink();
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) :  get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;    

// Recommended Packages section content details.
add_filter( 'moun10_pro_filter_recommended_package_section_details', 'moun10_pro_get_recommended_package_section_details' );


if ( ! function_exists( 'moun10_pro_render_recommended_package_section' ) ) :
  /**
   * Start Recommended Packages section
   *
   * @return string Recommended Packages content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_recommended_package_section( $content_details = array() ) {
        $options                = moun10_pro_get_theme_options();
        $taxonomy               = isset($content_details['taxonomy']) ? $content_details['taxonomy'] : 'category';
        $recommended_package_btn_title      = !empty( $options['recommended_package_btn_label'] ) ?  $options['recommended_package_btn_label'] : '' ;
        if ( empty( $content_details ) ) {
           return;
        } ?>
        <div id="moun10_pro_recommended_package_section">
            <div id="recommended-packages" class="relative page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                      <?php moun10_pro_section_tooltip( 'recommended-packages' ); ?>
                  <?php endif ?>
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html($options['recommended_package_sub_title'])?></p>
                    <h2 class="section-title"><?php echo esc_html($options['recommended_package_title'])?></h2>
                    </div><!-- .section-header -->   

                    <div class="section-content col-3 clear">
                        <?php foreach ($content_details['details'] as $content): ?>

                            <article>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']);?></p>
                                    </div><!-- .entry-content -->

                                    <div class="more-link">
                                        <a href="#" class="btn">Book Now</a>
                                    </div><!-- .more-link -->
                                </div><!-- .entry-container -->
                            </article>
                        <?php endforeach; ?>

                    </div><!-- .section-content -->

                    <?php if(!empty($recommended_package_btn_title)  && !empty(  $options['recommended_package_btn_url'] )): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $options['recommended_package_btn_url'] ); ?>" class="btn"><?php echo esc_html($recommended_package_btn_title); ?></a>
                        </div><!-- .read-more -->
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div>
        
        </div>
            
    <?php }
endif;