<?php
/**
 * Banner section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_slider_section() {
    	$options = moun10_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'moun10_pro_section_status', true, 'slider_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design', 'sixth-design', 'seventh-design' ) ) ) {
             $slider_enable = false;
        }

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        moun10_pro_render_slider_section( $section_details );
}

endif;

if ( ! function_exists( 'moun10_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input slider section details.
    */
    function moun10_pro_get_slider_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        // Content type.
        $slider_content_type    = $options['slider_content_type'];
        $slider_count           = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 4;
        
        $content = array();
        switch ( $slider_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $slider_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_category'] ) ? $options['slider_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $slider_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['author']    = moun10_pro_author();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'moun10_pro_filter_slider_section_details', 'moun10_pro_get_slider_section_details' );


if ( ! function_exists( 'moun10_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_slider_section( $content_details = array() ) {
        $options = moun10_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="moun10_pro_slider_section">
             <div id="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo $options['slider_autoplay_enable']; ?>, "draggable": true, "fade": true }'>
                <?php 
                    $i = 1;
                    foreach ( $content_details as $content ) : ?>
                        <article style="background-image: url('<?php echo esc_url( $content['image']); ?>');">
                            <div class="wrapper">
                                
                                <div class="featured-content-wrapper">
                                    <?php if ( is_customize_preview()): ?>
                                        <?php moun10_pro_section_tooltip( 'featured-slider' ); ?>
                                    <?php endif ?>
                                    <header class="entry-header">
                                        <?php if ( !empty( $options['slider_section_sub_title_'.$i] ) ): ?>
                                            <p class="section-subtitle"><?php echo esc_html( $options['slider_section_sub_title_'.$i] ); ?></p>
                                        <?php endif ?>
                                        
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="read-more">
                                        <?php if(!empty($options['slider_btn_txt'])) echo sprintf( '<a href="%s" class="btn">%s</a>', esc_url($content['url']), esc_html($options['slider_btn_txt']) ); ?>
                                        <?php if(!empty($options['slider_btn_alt_txt']) && !empty($options['slider_btn_alt_url'])) echo sprintf( '<a href="%s" class="btn">%s</a>', esc_url($options['slider_btn_alt_url']), esc_html($options['slider_btn_alt_txt']) ); ?>
                                    </div><!-- .read-more -->
                                </div>
                            </div><!-- .wrapper -->
                        </article>
                <?php $i++;
                    endforeach; ?>
           </div><!-- #featured-slider -->
        </div>
       
    <?php
    }    
endif;

